package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.WorkerSign;

/**
 * 师傅签到记录Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IWorkerSignService 
{
    /**
     * 查询师傅签到记录
     * 
     * @param id 师傅签到记录主键
     * @return 师傅签到记录
     */
    public WorkerSign selectWorkerSignById(Long id);

    /**
     * 查询师傅签到记录列表
     * 
     * @param workerSign 师傅签到记录
     * @return 师傅签到记录集合
     */
    public List<WorkerSign> selectWorkerSignList(WorkerSign workerSign);

    /**
     * 新增师傅签到记录
     * 
     * @param workerSign 师傅签到记录
     * @return 结果
     */
    public int insertWorkerSign(WorkerSign workerSign);

    /**
     * 修改师傅签到记录
     * 
     * @param workerSign 师傅签到记录
     * @return 结果
     */
    public int updateWorkerSign(WorkerSign workerSign);

    /**
     * 批量删除师傅签到记录
     * 
     * @param ids 需要删除的师傅签到记录主键集合
     * @return 结果
     */
    public int deleteWorkerSignByIds(Long[] ids);

    /**
     * 删除师傅签到记录信息
     * 
     * @param id 师傅签到记录主键
     * @return 结果
     */
    public int deleteWorkerSignById(Long id);
}
