package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.WorkerSign;
import com.ruoyi.system.service.IWorkerSignService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 师傅签到记录Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/WorkerSign")
public class WorkerSignController extends BaseController
{
    @Autowired
    private IWorkerSignService workerSignService;

    /**
     * 查询师傅签到记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerSign:list')")
    @GetMapping("/list")
    public TableDataInfo list(WorkerSign workerSign)
    {
        startPage();
        List<WorkerSign> list = workerSignService.selectWorkerSignList(workerSign);
        return getDataTable(list);
    }

    /**
     * 导出师傅签到记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerSign:export')")
    @Log(title = "师傅签到记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkerSign workerSign)
    {
        List<WorkerSign> list = workerSignService.selectWorkerSignList(workerSign);
        ExcelUtil<WorkerSign> util = new ExcelUtil<WorkerSign>(WorkerSign.class);
        util.exportExcel(response, list, "师傅签到记录数据");
    }

    /**
     * 获取师傅签到记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerSign:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(workerSignService.selectWorkerSignById(id));
    }

    /**
     * 新增师傅签到记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerSign:add')")
    @Log(title = "师傅签到记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkerSign workerSign)
    {
        return toAjax(workerSignService.insertWorkerSign(workerSign));
    }

    /**
     * 修改师傅签到记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerSign:edit')")
    @Log(title = "师傅签到记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkerSign workerSign)
    {
        return toAjax(workerSignService.updateWorkerSign(workerSign));
    }

    /**
     * 删除师傅签到记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerSign:remove')")
    @Log(title = "师傅签到记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(workerSignService.deleteWorkerSignByIds(ids));
    }
}
